==> readyapi-0.109.2.tar.gz: readyapi-0.109.2/docs/em/docs/history-design-future.md <==
# 📖, 🔧 &amp; 🔮

🕰 🏁, <a href="https://github.com/khulnasoft/readyapi/issues/3#issuecomment-454956920" class="external-link" target="_blank"> **ReadyAPI** 👩‍💻 💭</a>:

&gt; ⚫️❔ 📖 👉 🏗 ❓ ⚫️ 😑 ✔️ 👟 ⚪️➡️ 🕳 👌 👩‍❤‍👨 🗓️ [...]

📥 🐥 🍖 👈 📖.

## 🎛

👤 ✔️ 🏗 🔗 ⏮️ 🏗 📄 📚 1️⃣2️⃣🗓️ (🎰 🏫, 📎 ⚙️, 🔁 👨‍🏭, ☁ 💽, ♒️), ↘️ 📚 🏉 👩‍💻.

🍕 👈, 👤 💪 🔬, 💯 &amp; ⚙️ 📚 🎛.

📖 **ReadyAPI** 👑 🍕 📖 🚮 ⏪.

🙆‍♀ 📄 [🎛](alternatives.md){.internal-link target=_blank}:

<blockquote markdown="1">

**ReadyAPI** 🚫🔜 🔀 🚥 🚫 ⏮️ 👷 🎏.

📤 ✔️ 📚 🧰 ✍ ⏭ 👈 ✔️ ℹ 😮 🚮 🏗.

👤 ✔️ ❎ 🏗 🆕 🛠️ 📚 1️⃣2️⃣🗓️. 🥇 👤 🔄 ❎ 🌐 ⚒ 📔 **ReadyAPI** ⚙️ 📚 🎏 🛠️, 🔌-🔌, &amp; 🧰.

✋️ ☝, 📤 🙅‍♂ 🎏 🎛 🌘 🏗 🕳 👈 🚚 🌐 👫 ⚒, ✊ 🏆 💭 ⚪️➡️ ⏮️ 🧰, &amp; 🌀 👫 🏆 🌌 💪, ⚙️ 🇪🇸 ⚒ 👈 ➖🚫 💪 ⏭ (🐍 3️⃣.6️⃣ ➕ 🆎 🔑).

</blockquote>

## 🔬

⚙️ 🌐 ⏮️ 🎛 👤 ✔️ 🤞 💡 ⚪️➡️ 🌐 👫, ✊ 💭, &amp; 🌀 👫 🏆 🌌 👤 💪 🔎 👤 &amp; 🏉 👩‍💻 👤 ✔️ 👷 ⏮️.

🖼, ⚫️ 🆑 👈 🎲 ⚫️ 🔜 ⚓️ 🔛 🐩 🐍 🆎 🔑.

, 🏆 🎯 ⚙️ ⏪ ♻ 🐩.

, ⏭ ▶️ 📟 **ReadyAPI**, 👤 💸 📚 🗓️ 🎓 🔌 🗄, 🎻 🔗, Oauth2️⃣, ♒️. 🎯 👫 💛, 🔀, &amp; 🔺.

## 🔧

⤴️ 👤 💸 🕰 🔧 👩‍💻 "🛠️" 👤 💚 ✔️ 👩‍💻 (👩‍💻 ⚙️ ReadyAPI).

👤 💯 📚 💭 🏆 🌟 🐍 👨‍🎨: 🗒, 🆚 📟, 🎠 🧢 👨‍🎨.

🏁 <a href="https://www.jetbrains.com/research/python-developers-survey-2018/#development-tools" class="external-link" target="_blank">🐍 👩‍💻 🔬</a>, 👈 📔 🔃 8️⃣0️⃣ 💯 👩‍💻.

⚫️ ⛓ 👈 **ReadyAPI** 🎯 💯 ⏮️ 👨‍🎨 ⚙️ 8️⃣0️⃣ 💯 🐍 👩‍💻. &amp; 🏆 🎏 👨‍🎨 😑 👷 ➡, 🌐 🚮 💰 🔜 👷 🌖 🌐 👨‍🎨.

👈 🌌 👤 💪 🔎 🏆 🌌 📉 📟 ❎ 🌅 💪, ✔️ 🛠️ 🌐, 🆎 &amp; ❌ ✅, ♒️.

🌐 🌌 👈 🚚 🏆 🛠️ 💡 🌐 👩‍💻.

## 📄

⏮️ 🔬 📚 🎛, 👤 💭 👈 👤 🔜 ⚙️ <a href="https://pydantic-docs.helpmanual.io/" class="external-link" target="_blank">**Pydantic**</a> 🚮 📈.

⤴️ 👤 📉 ⚫️, ⚒ ⚫️ 🍕 🛠️ ⏮️ 🎻 🔗, 🐕‍🦺 🎏 🌌 🔬 ⚛ 📄, &amp; 📉 👨‍🎨 🐕‍🦺 (🆎 ✅, ✍) ⚓️ 🔛 💯 📚 👨‍🎨.

⏮️ 🛠️, 👤 📉 <a href="https://www.starlette.io/" class="external-link" target="_blank">**💃**</a>, 🎏 🔑 📄.

## 🛠️

🕰 👤 ▶️ 🏗 **ReadyAPI** ⚫️, 🏆 🍖 ⏪ 🥉, 🔧 🔬, 📄 &amp; 🧰 🔜, &amp; 💡 🔃 🐩 &amp; 🔧 🆑 &amp; 🍋.

## 🔮

👉 ☝, ⚫️ ⏪ 🆑 👈 **ReadyAPI** ⏮️ 🚮 💭 ➖ ⚠ 📚 👫👫.

⚫️ 💆‍♂ 👐 🤭 ⏮️ 🎛 ♣ 📚 ⚙️ 💼 👍.

📚 👩‍💻 &amp; 🏉 ⏪ 🪀 🔛 **ReadyAPI** 👫 🏗 (🔌 👤 &amp; 👇 🏉).

✋️, 📤 📚 📈 &amp; ⚒ 👟.

**ReadyAPI** ✔️ 👑 🔮 ⤴️.

&amp; [👆 ℹ](help-readyapi.md){.internal-link target=_blank} 📉 👍.

==> readyapi-0.110.1.tar.gz: readyapi-0.110.1/docs/em/docs/history-design-future.md <==
# 📖, 🔧 &amp; 🔮

🕰 🏁, <a href="https://github.com/khulnasoft/readyapi/issues/3#issuecomment-454956920" class="external-link" target="_blank"> **ReadyAPI** 👩‍💻 💭</a>:

&gt; ⚫️❔ 📖 👉 🏗 ❓ ⚫️ 😑 ✔️ 👟 ⚪️➡️ 🕳 👌 👩‍❤‍👨 🗓️ [...]

📥 🐥 🍖 👈 📖.

## 🎛

👤 ✔️ 🏗 🔗 ⏮️ 🏗 📄 📚 1️⃣2️⃣🗓️ (🎰 🏫, 📎 ⚙️, 🔁 👨‍🏭, ☁ 💽, ♒️), ↘️ 📚 🏉 👩‍💻.

🍕 👈, 👤 💪 🔬, 💯 &amp; ⚙️ 📚 🎛.

📖 **ReadyAPI** 👑 🍕 📖 🚮 ⏪.

🙆‍♀ 📄 [🎛](alternatives.md){.internal-link target=_blank}:

<blockquote markdown="1">

**ReadyAPI** 🚫🔜 🔀 🚥 🚫 ⏮️ 👷 🎏.

📤 ✔️ 📚 🧰 ✍ ⏭ 👈 ✔️ ℹ 😮 🚮 🏗.

👤 ✔️ ❎ 🏗 🆕 🛠️ 📚 1️⃣2️⃣🗓️. 🥇 👤 🔄 ❎ 🌐 ⚒ 📔 **ReadyAPI** ⚙️ 📚 🎏 🛠️, 🔌-🔌, &amp; 🧰.

✋️ ☝, 📤 🙅‍♂ 🎏 🎛 🌘 🏗 🕳 👈 🚚 🌐 👫 ⚒, ✊ 🏆 💭 ⚪️➡️ ⏮️ 🧰, &amp; 🌀 👫 🏆 🌌 💪, ⚙️ 🇪🇸 ⚒ 👈 ➖🚫 💪 ⏭ (🐍 3️⃣.6️⃣ ➕ 🆎 🔑).

</blockquote>

## 🔬

⚙️ 🌐 ⏮️ 🎛 👤 ✔️ 🤞 💡 ⚪️➡️ 🌐 👫, ✊ 💭, &amp; 🌀 👫 🏆 🌌 👤 💪 🔎 👤 &amp; 🏉 👩‍💻 👤 ✔️ 👷 ⏮️.

🖼, ⚫️ 🆑 👈 🎲 ⚫️ 🔜 ⚓️ 🔛 🐩 🐍 🆎 🔑.

, 🏆 🎯 ⚙️ ⏪ ♻ 🐩.

, ⏭ ▶️ 📟 **ReadyAPI**, 👤 💸 📚 🗓️ 🎓 🔌 🗄, 🎻 🔗, Oauth2️⃣, ♒️. 🎯 👫 💛, 🔀, &amp; 🔺.

## 🔧

⤴️ 👤 💸 🕰 🔧 👩‍💻 "🛠️" 👤 💚 ✔️ 👩‍💻 (👩‍💻 ⚙️ ReadyAPI).

👤 💯 📚 💭 🏆 🌟 🐍 👨‍🎨: 🗒, 🆚 📟, 🎠 🧢 👨‍🎨.

🏁 <a href="https://www.jetbrains.com/research/python-developers-survey-2018/#development-tools" class="external-link" target="_blank">🐍 👩‍💻 🔬</a>, 👈 📔 🔃 8️⃣0️⃣ 💯 👩‍💻.

⚫️ ⛓ 👈 **ReadyAPI** 🎯 💯 ⏮️ 👨‍🎨 ⚙️ 8️⃣0️⃣ 💯 🐍 👩‍💻. &amp; 🏆 🎏 👨‍🎨 😑 👷 ➡, 🌐 🚮 💰 🔜 👷 🌖 🌐 👨‍🎨.

👈 🌌 👤 💪 🔎 🏆 🌌 📉 📟 ❎ 🌅 💪, ✔️ 🛠️ 🌐, 🆎 &amp; ❌ ✅, ♒️.

🌐 🌌 👈 🚚 🏆 🛠️ 💡 🌐 👩‍💻.

## 📄

⏮️ 🔬 📚 🎛, 👤 💭 👈 👤 🔜 ⚙️ <a href="https://docs.pydantic.dev/" class="external-link" target="_blank">**Pydantic**</a> 🚮 📈.

⤴️ 👤 📉 ⚫️, ⚒ ⚫️ 🍕 🛠️ ⏮️ 🎻 🔗, 🐕‍🦺 🎏 🌌 🔬 ⚛ 📄, &amp; 📉 👨‍🎨 🐕‍🦺 (🆎 ✅, ✍) ⚓️ 🔛 💯 📚 👨‍🎨.

⏮️ 🛠️, 👤 📉 <a href="https://www.starlette.io/" class="external-link" target="_blank">**💃**</a>, 🎏 🔑 📄.

## 🛠️

🕰 👤 ▶️ 🏗 **ReadyAPI** ⚫️, 🏆 🍖 ⏪ 🥉, 🔧 🔬, 📄 &amp; 🧰 🔜, &amp; 💡 🔃 🐩 &amp; 🔧 🆑 &amp; 🍋.

## 🔮

👉 ☝, ⚫️ ⏪ 🆑 👈 **ReadyAPI** ⏮️ 🚮 💭 ➖ ⚠ 📚 👫👫.

⚫️ 💆‍♂ 👐 🤭 ⏮️ 🎛 ♣ 📚 ⚙️ 💼 👍.

📚 👩‍💻 &amp; 🏉 ⏪ 🪀 🔛 **ReadyAPI** 👫 🏗 (🔌 👤 &amp; 👇 🏉).

✋️, 📤 📚 📈 &amp; ⚒ 👟.

**ReadyAPI** ✔️ 👑 🔮 ⤴️.

&amp; [👆 ℹ](help-readyapi.md){.internal-link target=_blank} 📉 👍.
